from distutils.core import setup 
setup(name = "quickcal", 
version = "2.1", 
description = "fast and easy to use calculator with support for filing", 
author = "Nathan SR", 
author_email = "cquickcal@gmail.com",
url = "https://git.fosscommunity.in/SRNathan/Quickcal_Calculator", 
license='GPLv3', 
scripts=['quickcal'], 
data_files = [ ("lib/quickcal", ["quickcal.glade"]), 
("share/pixmaps", ["quickcal.png"]),
("share/pixmaps", ["quickcal_small.png"]),
("share/man/man1", ["quickcal.1.gz"]),
("share/man/man1", ["num.1.gz"]),
("bin", ["num"]), 
("share/applications", ["quickcal.desktop"]) ] ) 
